Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProdocsConfig ¶
type ProdocsConfig struct {
// Port is the HTTP port at which the prodocs service will be available
Port string `yaml:"port" json:"port"`
// PAT is the GitHub PAT used to authenticate when cloning repositories
PAT string `yaml:"PAT" json:"PAT"`
// Repositories is the list of git repositories that need to be cloned
Repositories []Repository `yaml:"repositories" json:"repositories"`
// StoragePath is path at which the cloned repositories are stored
StoragePath string `yaml:"storagePath" json:"storagePath"`
// OutputPath is the path at which the output html files will be stored
OutputPath string `yaml:"outputPath" json:"outputPath"`
}
ProdocsConfig is the config schema for the main prodocs application
func NewProdocsConfig ¶
func NewProdocsConfig(path string) (*ProdocsConfig, error)
NewProdocsConfig initialises a new config object from a YAML file
type ProdocsProjectConfig ¶
type ProdocsProjectConfig struct {
Name string `yaml:"name"`
Url string `yaml:"url"`
Author struct {
Name string
Email string
} `yaml:"author"`
IncludePrefixes []string `yaml:"includePrefixes"`
ExcludePrefixes []string `yaml:"excludePrefixes"`
}
func NewProdocsProjectConfig ¶
func NewProdocsProjectConfig(path string) (*ProdocsProjectConfig, error)
type Repository ¶
Click to show internal directories.
Click to hide internal directories.